# Channel Mixer


::: linax.channel_mixers.base.ChannelMixerConfig
    options:
        members:
            - build

---

::: linax.channel_mixers.base.ChannelMixer
    options:
        members:
            - __init__
            - __call__
